==> haskell-yesod-form-1.4.7-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod-form/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.7
id: yesod-form-1.4.7-6a275c9e9130fcb166b96e9c28a6cb8b
key: yesod_H6JVbIXEpxKH5uqsQBu3QX
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Types Yesod.Form.Functions
    Yesod.Form.Bootstrap3 Yesod.Form.Input Yesod.Form.Fields
    Yesod.Form.Jquery Yesod.Form.Nic Yesod.Form.MassInput
    Yesod.Form.I18n.English Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Swedish Yesod.Form.I18n.German
    Yesod.Form.I18n.French Yesod.Form.I18n.Norwegian
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Dutch
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-form-1.4.7
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-form-1.4.7
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-form-1.4.7
hs-libraries: HSyesod-form-1.4.7-H6JVbIXEpxKH5uqsQBu3QX
depends:
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    email-validate-2.2.0-2cb19fcad74f009f580f5d1a0c1a07e6
    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
    persistent-2.2.4.1-06cdd104cf52ce01e8563b1ef8106c7c
    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
    xss-sanitize-0.3.5.6-f78b5b03aa1efe6d65b9961065a15c78
    yesod-core-1.4.20-b033425e59f14830b0f582c5aa97dfc9
    yesod-persistent-1.4.0.4-ad1a95adedfa128856dec4233422bbe5
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.4.7-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-yesod-form/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.7
id: yesod-form-1.4.7-6556fa2dbba4c60b35adfc5077eb6d41
key: yesod_6oAEK7hOa15JOKXtaIGnXZ
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Types Yesod.Form.Functions
    Yesod.Form.Bootstrap3 Yesod.Form.Input Yesod.Form.Fields
    Yesod.Form.Jquery Yesod.Form.Nic Yesod.Form.MassInput
    Yesod.Form.I18n.English Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Swedish Yesod.Form.I18n.German
    Yesod.Form.I18n.French Yesod.Form.I18n.Norwegian
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Dutch
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-form-1.4.7
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-form-1.4.7
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-form-1.4.7
hs-libraries: HSyesod-form-1.4.7-6oAEK7hOa15JOKXtaIGnXZ
depends:
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
    email-validate-2.2.0-2cb19fcad74f009f580f5d1a0c1a07e6
    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
    persistent-2.2.4.1-840a8f388c4f74e927e97d9dd2d8494d
    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
    xss-sanitize-0.3.5.6-f78b5b03aa1efe6d65b9961065a15c78
    yesod-core-1.4.20.1-8dce2c1559c72b98aae15f98b85f32e0
    yesod-persistent-1.4.0.4-05d2e78a4f4be2f611edc21702f1c928
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
